@@ -238,7 +238,14 @@ public class DBBankLogger {
 		ct.setNbFilesLocalOffline(Integer.valueOf(arg0.getProject().getProperty(BiomajConst.countLocalOfflineFileProperty)));
 		
 		boolean fileCopyNeed =  Boolean.valueOf(arg0.getProject().getProperty(BiomajConst.filesCopyNeedDynamicProperty));
-		bank.setUpdate(fileCopyNeed || (ct.getNbFilesDownload()>0) || (ct.getNbFilesLocalOffline()>0));
+		if (arg0.getProject().getProperty("isComputedAndEmpty") != null &&
+				arg0.getProject().getProperty("isComputedAndEmpty").equals("true") &&
+				arg0.getProject().getProperty("children.updated") != null &&
+				arg0.getProject().getProperty("children.updated").equals("true")) {
+			bank.setUpdate(true);
+		} else {
+			bank.setUpdate(fileCopyNeed || (ct.getNbFilesDownload()>0) || (ct.getNbFilesLocalOffline()>0));
+		}
 		
 		DBWriter.updateStateSession(bank,false);
 	}
@@ -310,12 +317,17 @@ public class DBBankLogger {
 				} catch (IOException e) {
 					project.log(e.getMessage(), Project.MSG_ERR);
 				}
+			} else {
+				System.out.println(current.getAbsolutePath() + " doesnt exist");
 			}
 		}
 	}
 
 	public void actionDeployement(BuildEvent arg0) throws BiomajException {
 		bank.setWorkflowInfoIsDeployed(true);
+		String computedAndEmpty = arg0.getProject().getProperty("isComputedAndEmpty");
+		if (computedAndEmpty != null && computedAndEmpty.equals("true"))
+			bank.setWorkflowInfoProductionDir(BiomajUtils.getNameDirectoryCurrentRelease(arg0.getProject()));
 		bank.addProductionDirectory(bank.getWorkflowInfoProductionDir());
 		DBWriter.updateStateSession(bank,false);
 		DBWriter.updateStateSessionWithProductionDir(bank);
@@ -330,17 +342,17 @@ public class DBBankLogger {
 	}
 	
 	public void versionsmanagementFinishedTask(BuildEvent arg0) throws BiomajException {
-
+		
 		String mode = arg0.getProject().getProperty(BmajVersionManagement.MODE);
 		String directories = arg0.getProject().getProperty(BmajVersionManagement.RESULTS);
 
 		arg0.getProject().log("MODE:"+mode+" RESULTS:"+directories,Project.MSG_DEBUG);
 		if ((BmajVersionManagement.DELETE.compareTo(mode)==0)||(BmajVersionManagement.REBUILD.compareTo(mode)==0)) {
 			String[] dirs = directories.split(",");
-			for (int i=0;i<dirs.length;i++)
+			for (int i=0;i<dirs.length;i++) {
 				bank.removeProductionDirectory(dirs[i]);
+			}
 			DBWriter.updateStateSessionWithProductionDir(bank);
-		} else {
 		}
 	}
 
@@ -561,15 +573,14 @@ public class DBBankLogger {
 		Pattern p = Pattern.compile(BmajTask.filterAddExtractedFile+BmajTask.regExpAddExtractedFile);
 		Matcher m = p.matcher(message);
 
-		if (!m.find())
-		{
+		if (!m.find()) {
 			BiomajLogger.getInstance().log("Can't add extraction file (can't parse:"+message+")");
 			return;
 		}
 		
 		String fileUncompressed = m.group(1);
 		String refHash = m.group(2);
-
+		
 		bank.addFilesInExtraction(fileUncompressed,refHash);
 //		DBWriter.updateStateSession(bank,false);
 	}
@@ -635,5 +646,9 @@ public class DBBankLogger {
 		
 		DBWriter.updateStateSession(bank,false);
 	}
+	
+	public Bank getBank() {
+		return bank;
+	}
 
 }
