@@ -41,6 +41,7 @@
 
 package org.inria.biomaj.ant.logger;
 
+import java.io.File;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
@@ -50,6 +51,8 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Vector;
 
+import org.inria.biomaj.exe.bank.BankFactory;
+import org.inria.biomaj.exe.bank.BiomajBank;
 import org.inria.biomaj.session.bank.Bank;
 import org.inria.biomaj.session.bank.BiomajSQLQuerier;
 import org.inria.biomaj.session.bank.Configuration;
@@ -111,6 +114,7 @@ public class DBWriter {
 		long confId = BiomajSQLQuerier.getLatestConfigurationWithSession((int) getBankId(bank.getConfig().getName()), false);
 		Session session = bank.getCurrentSession();
 		long updateId = -1;
+		
 		if (newSession) { // Create a new session element
 			if (bank.getListOldSession().size() == 0 || // If the session is ok and is not a removeprocess
 					(bank.getListOldSession().get(bank.getListOldSession().size() - 1).getStatus()
@@ -183,6 +187,7 @@ public class DBWriter {
 		
 		GeneralWorkflowTask p1 = session.getLastTask();
 		GeneralWorkflowTask p2 = session.getActiveTask();
+		
 		if (p1 != null) {
 			setElementTaskWorkflow(p1);
 		} else if (p2 != p1 && p2 != null) {
@@ -193,44 +198,6 @@ public class DBWriter {
 		addMessages("warning",session.getNewWarn(),session.getId().toString(),"session");
 		addMessages("error",session.getNewErr(), session.getId().toString(), "session");
 		
-		/*
-		String bankName = bank.getConfig().getName();
-		int id = BiomajSQLQuerier.getBankId(bankName);
-		long updateId = -1;
-
-		if (BiomajSQLQuerier.getConfigCount(bankName) > 0) {
-			
-			String query = "SELECT idconfiguration FROM configuration WHERE ref_idbank=" + id +
-					" AND date = (SELECT MAX(date) FROM configuration WHERE ref_idbank = " +
-					id + ");";
-			connection.executeQuery(query, true);
-			long confId = 0;
-			try {
-				connection.getResult().next();
-				confId = connection.getResult().getLong(1);
-				connection.closeStatement();
-			} catch (SQLException e) {
-				e.printStackTrace();
-			}
-			if (newSession) {
-				updateId = createUpdateBank(bank, confId, -1);
-			}
-			else {
-				query = "SELECT max(idupdateBank) FROM updateBank WHERE ref_idconfiguration=" + confId;
-				connection.executeQuery(query, true);
-				try {
-					if (connection.getResult().next()) {
-						updateId = createUpdateBank(bank, confId, connection.getResult().getInt(1));
-						connection.closeStatement();
-					}
-				} catch (SQLException e) {
-					e.printStackTrace();
-				}
-			}
-			
-			return updateId;
-		} else
-			return -1;*/
 	}
 	
 	/**
@@ -478,15 +445,14 @@ public class DBWriter {
 		
 	}
 
-	public synchronized static void updateStateSessionWithProductionDir(Bank xmlBank) throws BiomajException {
-
-		if (xmlBank==null)
+	public synchronized static void updateStateSessionWithProductionDir(Bank bank) throws BiomajException {
+		if (bank==null)
 			return ;
 
-		if (xmlBank.getConfig() == null)
+		if (bank.getConfig() == null)
 			throw new NullPointerException("Config bank can't be null");
 
-		createContentProductionDirectories(xmlBank.getBankStateListProductionDirectories(), getBankId(xmlBank.getConfig().getName()));
+		createContentProductionDirectories(bank.getBankStateListProductionDirectories(), getBankId(bank.getConfig().getName()));
 	}
 	
 	public static synchronized long getBankId(String bankName) {
@@ -494,7 +460,21 @@ public class DBWriter {
 		
 		long bankId = BiomajSQLQuerier.getBankId(bankName);
 		if (bankId < 0) {
-			String query = "INSERT INTO bank(name) values('" + bankName + "');";
+			int userId = getBankOwnerId(bankName);
+			
+			String visibility = "false";
+			BankFactory bf = new BankFactory();
+			try {
+				BiomajBank bb = bf.createBank(bankName, false);
+				String tmp = bb.getPropertiesFromBankFile().getProperty(BiomajConst.bankVisibility);
+				if (tmp != null) {
+					visibility = tmp.equals("public") ? "true" : "false";
+				}
+			} catch (BiomajException e) {
+				e.printStackTrace();
+			}
+			
+			String query = "INSERT INTO bank(name, ref_iduser, visibility) values('" + bankName + "'," + userId + "," + visibility + ");";
 			Statement stat = connection.getStatement();
 			bankId = connection.executeUpdateAndGetGeneratedKey(query, stat);
 			SQLConnectionFactory.closeConnection(stat);
@@ -502,19 +482,35 @@ public class DBWriter {
 		return bankId;
 	}
 
-	public synchronized static void reWriteWithProductionDir(String bankName,ProductionDirectory pd) throws BiomajException {
+	public synchronized static void setProductionDirRemoved(String bankName,ProductionDirectory pd) throws BiomajException {
 
 		if (bankName==null)
 			return ;
 
 		long id = getBankId(bankName);
-		String query = "UPDATE productionDirectory SET remove='" + BiomajUtils.dateToString(pd.getRemoveDate(), Locale.US) + "'," +
-				"state='" + ProductionDirectory.REMOVE_STR + "' WHERE ref_idbank=" + id + " AND path='" + pd.getPath() + "'" +
-						" AND state='" + ProductionDirectory.AVAILABLE_STR + "';";
-
+		String query = "SELECT idproductionDirectory FROM productionDirectory WHERE ref_idbank=" + id + " AND path='" + pd.getPath() + "' AND " +
+				"state='" + ProductionDirectory.AVAILABLE_STR + "'";
+		
 		Statement stat = connection.getStatement();
+		ResultSet rs = connection.executeQuery(query, stat);
+		int pdId = -1;
+		try {
+			if (rs.next()) {
+				pdId = rs.getInt(1);
+			}
+		} catch (SQLException e) {
+			e.printStackTrace();
+			SQLConnectionFactory.closeConnection(stat);
+			return;
+		}
+		
+		query = "UPDATE productionDirectory SET remove='" + BiomajUtils.dateToString(pd.getRemoveDate(), Locale.US) + "'," +
+				"state='" + ProductionDirectory.REMOVE_STR + "' WHERE idproductionDirectory=" + pdId;
+
 		connection.executeUpdate(query, stat);
 		SQLConnectionFactory.closeConnection(stat);
+		
+		BiomajSQLQuerier.deleteRemovedDirectoryRelatedRecords(pdId);
 	}
 	
 	public static synchronized void deleteBank(String bankName) {
@@ -648,6 +644,7 @@ public class DBWriter {
 		}
 		
 		p.setTaskId((int) taskId);
+		
 		p.fillElement(taskId);
 
 		addMessages("warning",p.getNewWarn(), String.valueOf(taskId), "task");
@@ -957,20 +954,27 @@ public class DBWriter {
 	private static void createContentProductionDirectories(Vector<ProductionDirectory> listDir, long idBank) {
 		for (ProductionDirectory pd : listDir) {
 			
-			String query = "SELECT idproductionDirectory FROM productionDirectory WHERE path='" + pd.getPath() + "'" +
+			String query = "SELECT idproductionDirectory,state FROM productionDirectory WHERE path='" + pd.getPath() + "'" +
 					" AND session=" + pd.getSession() + ";";
+			
 			Statement stat = connection.getStatement();
 			try {
 				ResultSet rs = connection.executeQuery(query, stat);
 				if (rs.next()) {
 					int id = rs.getInt(1);
+					String oldState = rs.getString(2);
 					SQLConnectionFactory.closeConnection(stat);
 					
+					
+					
 					query = "UPDATE productionDirectory SET " +
 							"remove=" + (pd.getRemoveDate() == null ? "null," : "'" + BiomajUtils.dateToString(pd.getRemoveDate(), Locale.US) + "',") +
-							"creation='" + BiomajUtils.dateToString(pd.getCreationDate(), Locale.US) + "'," +
-							"size='" + BiomajUtils.sizeToString(pd.getSize()) + "'," +
-							"state='" + pd.getStateStr() + "'," +
+							"creation='" + BiomajUtils.dateToString(pd.getCreationDate(), Locale.US) + "',";
+					
+					if (pd.getStateStr().equals(ProductionDirectory.AVAILABLE_STR)) {
+						query += "size='" + BiomajUtils.sizeToString(pd.getSize()) + "',";
+					}
+					query += "state='" + pd.getStateStr() + "'," +
 							"session='" + pd.getSession() + "'," +
 							"path='" + pd.getPath() + "'," +
 							"ref_idbank=" + idBank + " WHERE idproductionDirectory=" + id;
@@ -978,6 +982,12 @@ public class DBWriter {
 					stat = connection.getStatement();
 					connection.executeUpdate(query, stat);
 					SQLConnectionFactory.closeConnection(stat);
+					
+					if (oldState.equals(ProductionDirectory.AVAILABLE_STR) &&
+							pd.getStateStr().equals(ProductionDirectory.REMOVE_STR)) { // Directory just deleted
+						BiomajSQLQuerier.deleteRemovedDirectoryRelatedRecords(id);
+					}
+					
 				} else {
 					SQLConnectionFactory.closeConnection(stat);
 					query = "INSERT INTO productionDirectory(remove, creation, size, state, session, path, ref_idbank)" +
@@ -996,6 +1006,33 @@ public class DBWriter {
 		}
 	}
 	
+	public static int getBankOwnerId(String bankName) {
+		File file = BankFactory.getBankPath(bankName);
+		if (file == null)
+			return 1;
+		
+		String path = file.getAbsolutePath();
+		String np = path.substring(0, path.lastIndexOf('/'));
+		String user = np.substring(np.lastIndexOf('/') + 1);
+		
+		int id = 1;
+		String query = "SELECT iduser FROM bw_user WHERE login='" + user + "'";
+		Statement stat = connection.getStatement();
+		try {
+			ResultSet rs = connection.executeQuery(query, stat);
+			if (rs.next()) {
+				id = rs.getInt(1);
+			}
+		} catch (SQLException ex) {
+			SQLConnectionFactory.closeConnection(stat);
+			ex.printStackTrace();
+		}
+		SQLConnectionFactory.closeConnection(stat);
+		
+		return id;
+		
+	}
+	
 	/**
 	 * Id of metaprocess that may need to be deleted
 	 * in case of rebuild with no rerun of metaprocess.
