@@ -53,6 +53,7 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.Vector;
 import java.util.concurrent.Semaphore;
+
 import javax.mail.Address;
 import javax.mail.Message;
 import javax.mail.MessagingException;
@@ -160,12 +161,24 @@ public class RemoteBankWorkflowEngine extends WorkflowEngine {
 	protected void initWorkflow() throws BiomajException {
 		super.initWorkflow();
 		
+		
 		bProject = new BiomajAntProject();	
 		Properties props = getBiomajBank().getPropertiesFromBankFile();
 		props.put("fromScratch", String.valueOf(isFromScratch()));
-
+		
+		
+		if (!props.containsKey("ref.release"))
+			props.put("ref.release", "");
+		if (props.containsKey("db.source")) { // Computed bank
+			props.put("computed", "true");
+		} else {
+			props.put("computed", "false");
+		}
+		
+		
 		bProject.init(BiomajConst.mirrorXmlFile, props);
 		
+		
 		SimpleLoggerHistoric slh = BiomajLogger.getInstance().initLogger(getBiomajBank().getDbName(), "mirror.log");
 		if (slh != null)
 			bProject.addBuildListener(slh);
@@ -290,8 +303,7 @@ public class RemoteBankWorkflowEngine extends WorkflowEngine {
 		}
 
 		String stop = getProperty("stop.workflow");
-		if ((stop != null)&&(stop.compareTo("true")==0))
-		{
+		if ((stop != null)&&(stop.compareTo("true")==0)) {
 			killApplication() ;
 		}
 	}
@@ -299,7 +311,7 @@ public class RemoteBankWorkflowEngine extends WorkflowEngine {
 
 
 	@Override
-	public Vector<WorkflowEngine> getChild() {
+	public Vector<WorkflowEngine> getChildren() {
 		return new Vector<WorkflowEngine>();
 	}
 
@@ -317,6 +329,9 @@ public class RemoteBankWorkflowEngine extends WorkflowEngine {
 		runMirror();
 		runMakeProduction();
 		runPostProcess();
+		
+//		waitIfNeeded();
+		
 		runDeployment();
 		runDeleteOldVersion();
 		writeEnd();
@@ -557,7 +572,10 @@ public class RemoteBankWorkflowEngine extends WorkflowEngine {
 				BiomajLogger.getInstance().log(e);
 			}
 			try {
-				launchWithTarget("action_mirror");
+				if (bank.getConfig().getProtocol().equals("directhttp"))
+					launchWithTarget("action_direct_mirror");
+				else
+					launchWithTarget("action_mirror");
 			} catch (Exception e) {
 				throw new BiomajException(e);
 			} finally {
@@ -569,6 +587,7 @@ public class RemoteBankWorkflowEngine extends WorkflowEngine {
 	/**
 	 */
 	protected void runMakeProduction() throws BiomajException {
+
 		if (bank.workflowTaskEverPast(Session.MOVE)) {
 			log("Make directory production is ok....",Project.MSG_INFO);
 
@@ -616,9 +635,9 @@ public class RemoteBankWorkflowEngine extends WorkflowEngine {
 
 		boolean processLaunched = false;
 		if ((!getProject().getProperties().containsKey(BiomajConst.blockPostprocessProperty))||
-				(getProject().getProperty(BiomajConst.blockPostprocessProperty).trim().compareTo("")==0))
+				(getProject().getProperty(BiomajConst.blockPostprocessProperty).trim().compareTo("")==0)) {
 			processLaunched = runProcessesWithProperty(BiomajConst.dbPostProcessProperty,""); 
-		else {
+		} else {
 			processLaunched = executeBlockSequentially(BiomajConst.dbPostProcessProperty,getProject().getProperty(BiomajConst.blockPostprocessProperty));
 		}
 
@@ -695,7 +714,7 @@ public class RemoteBankWorkflowEngine extends WorkflowEngine {
 			return;
 
 		if (bank.workflowTaskEverPast(Session.DEPLOYMENT)) {
-			log("Deployement is ok....",Project.MSG_INFO);
+			log("Deployment is ok....",Project.MSG_INFO);
 			return ;
 		}
 
@@ -753,8 +772,8 @@ public class RemoteBankWorkflowEngine extends WorkflowEngine {
 				getBiomajBank().getPropertiesFromBankFile().getProperty(blockProperty).trim().compareTo("")!=0;
 
 		if (!conditionToProcess) {
-			if (BiomajConst.dbRemoveProcessProperty.compareTo(property)==0)
-				bank.setRemove(false);
+//			if (BiomajConst.dbRemoveProcessProperty.compareTo(property)==0)
+//				bank.setRemove(false);
 			
 			log("No parallel process defined! ("+property+" not set)", Project.MSG_INFO);
 			if (blh!=null) {
@@ -775,8 +794,8 @@ public class RemoteBankWorkflowEngine extends WorkflowEngine {
 		String[] list = list_proc_parallel.split(",");
 
 		if (list.length==0) {
-			if (BiomajConst.dbRemoveProcessProperty.compareTo(property)==0)
-				bank.setRemove(false);
+//			if (BiomajConst.dbRemoveProcessProperty.compareTo(property)==0)
+//				bank.setRemove(false);
 			
 			log("No parallel process defined! ("+blockProperty+" not set)", Project.MSG_INFO);
 			return false;
@@ -987,6 +1006,7 @@ public class RemoteBankWorkflowEngine extends WorkflowEngine {
 		} else {
 			log = BiomajLogger.getInstance().getFileNameGeneralLog();
 		}
+
 		throw new BiomajException("kill.application",log);
 	}
 
@@ -1211,8 +1231,7 @@ public class RemoteBankWorkflowEngine extends WorkflowEngine {
 
 
 	private String getMessageHeader(boolean isOk) {
-		if ((bank!=null)&&(bank.getConfig()!=null))
-		{
+		if (bank != null && bank.getConfig() != null) {
 			String h = "Biomaj message: BANK ["+bank.getConfig().getName()+"] - STATUS ["+Boolean.toString(isOk).toUpperCase()+"]" + " - UPDATE ["+Boolean.toString(bank.isUpdate()).toUpperCase()+"]";
 			if (bank.isUpdate()) 
 				h += " - RELEASE:"+bank.getWorkflowInfoRelease();
@@ -1291,8 +1310,8 @@ public class RemoteBankWorkflowEngine extends WorkflowEngine {
 			}
 			res+="\n";
 			res+="\n***********************************************\n";
-		}
-		else if (bank.isRemove()) {
+		} else if (bank.isRemove()) {
+			
 			res+="\n****************** INFO REMOVE ***************\n";
 
 			Collection<MetaProcess> lMpR = bank.getAvailableMetaProcess(Session.REMOVEPROCESS);
@@ -1312,13 +1331,15 @@ public class RemoteBankWorkflowEngine extends WorkflowEngine {
 			res+="\n***********************************************\n";
 		}
 
-		try {			
+		try {
+			/*
 			if (bank!=null)
 				for (Session s : bank.getListOldSession()) {
 					for (String d : s.getMessageErrorOnSession())
 						res+=d+"\n";
 				}
-
+			 */
+			
 			if ((bank!=null)&&(bank.getCurrentSession()!=null))
 				for (String s : bank.getCurrentSession().getMessageErrorOnSession())
 					res+=s+"\n";
@@ -1402,6 +1423,10 @@ public class RemoteBankWorkflowEngine extends WorkflowEngine {
 		if (prodDir.compareTo(new File(lastVersionDirectory))!=0) {
 			throw new BiomajBuildException(getProject(),"remotebankworkflow.error.change.versiondir", prodDir.getAbsolutePath(),null);
 		}
-	}	
+	}
+	
+	public BiomajMirrorListenerHandler getListener() {
+		return blh;
+	}
 
 }
