@@ -948,7 +948,6 @@ public class BiomajSQLQuerier {
 				"(SELECT ref_idsessionTask FROM session_has_sessionTask WHERE " +
 				"ref_idsession =" + sessionId + ");";
 		Statement stat = connection.getStatement();
-		
 		try {
 			ResultSet result = connection.executeQuery(query, stat);
 			while (result.next()) {
@@ -1705,29 +1704,47 @@ public class BiomajSQLQuerier {
 		deleteBank(bankName);
 		
 		int bankId = getBankId(bankName);
+		Statement stat = connection.getStatement();
 		
 		String query = "DELETE FROM productionDirectory WHERE ref_idbank=" + bankId;
-		
-		query = "DELETE FROM localInfo WHERE idlocalInfo IN (SELECT ref_idlocalInfo FROM configuration WHERE ref_idbank=" +
-				bankId + ")";
-		Statement stat = connection.getStatement();
 		connection.executeUpdate(query, stat);
-		SQLConnectionFactory.closeConnection(stat);
 		
-		query = "DELETE FROM remoteInfo WHERE idremoteInfo=(SELECT ref_idremoteInfo FROM configuration WHERE ref_idbank=" +
-				bankId + ")";
-		stat = connection.getStatement();
-		connection.executeUpdate(query, stat);
-		SQLConnectionFactory.closeConnection(stat);
 		
+		/*
+		 * Remoteinfo or localinfo cascade deletes configurations, so we need
+		 * to retrieved all remoteinfo and localinfo ids
+		 */
+		query = "SELECT ref_idlocalInfo, ref_idremoteInfo FROM configuration WHERE ref_idbank=" + bankId;
+		List<List<Long>> configIds = new ArrayList<List<Long>>(); 
+		try {
+			ResultSet rs = connection.executeQuery(query, stat);
+			while (rs.next()) {
+				List<Long> lst = new ArrayList<Long>();
+				lst.add(rs.getLong(1));
+				lst.add(rs.getLong(2));
+				configIds.add(lst);
+			}
+		} catch (SQLException e) {
+			e.printStackTrace();
+		}
+		if (configIds.size() > 0) {
+			for (List<Long> ids : configIds) {
+				String queryLocal = "DELETE FROM localInfo WHERE idlocalInfo=" + ids.get(0);
+				String queryRemote = "DELETE FROM remoteInfo WHERE idremoteInfo=" + ids.get(1);
+				
+				connection.executeUpdate(queryLocal, stat);
+				connection.executeUpdate(queryRemote, stat);
+			}
+			
+		}
+
+		// Delete configuration to double check
 		query = "DELETE FROM configuration WHERE ref_idbank=" + bankId;
-		stat = connection.getStatement();
 		connection.executeUpdate(query, stat);
-		SQLConnectionFactory.closeConnection(stat);
 		
 		query = "DELETE FROM bank WHERE name='" + bankName + "'";
-		stat = connection.getStatement();
 		connection.executeUpdate(query, stat);
+		
 		SQLConnectionFactory.closeConnection(stat);
 		
 	}
@@ -2000,5 +2017,78 @@ public class BiomajSQLQuerier {
 		connection.executeUpdate(query, stat);
 		SQLConnectionFactory.closeConnection(stat);
 	}
+	
+	public static synchronized void deleteRemovedDirectoryRelatedRecords(int productionDirectoryId) {
+		
+		BiomajLogger.getInstance().log("Deletion of removed directory related records", BiomajLogger.INFO_LEVEL);
+		
+		SQLConnection connection = SQLConnectionFactory.getConnection();
+		Statement stat = connection.getStatement();
+		// Delete sessionTask files
+		
+		String query = "DELETE FROM file WHERE idfile IN " +
+				"(SELECT ref_idfile FROM sessionTask_has_file WHERE ref_idsessionTask IN " +
+				"(SELECT ref_idsessionTask FROM session_has_sessionTask WHERE ref_idsession=" +
+				"(SELECT session FROM productionDirectory WHERE idproductionDirectory=" + productionDirectoryId +
+				")))";
+		
+		BiomajLogger.getInstance().log("Deleting sessionTask files", BiomajLogger.INFO_LEVEL);
+		connection.executeUpdate(query, stat);
+		
+		// Delete process files
+		query = "DELETE FROM file WHERE ref_idprocess IN " +
+				"(SELECT idprocess FROM process WHERE ref_idmetaprocess IN " +
+				"(SELECT idmetaprocess FROM metaprocess WHERE ref_idsessionTask IN " +
+				"(SELECT ref_idsessionTask FROM session_has_sessionTask WHERE ref_idsession=" +
+				"(SELECT session FROM productionDirectory WHERE idproductionDirectory=" + productionDirectoryId +
+				"))))";
+		
+		BiomajLogger.getInstance().log("Deleting process files", BiomajLogger.INFO_LEVEL);
+		connection.executeUpdate(query, stat);
+		
+		// Process messages
+		query = "DELETE FROM message WHERE idmessage IN " +
+				"(SELECT ref_idmessage FROM process_has_message WHERE ref_idprocess IN " +
+				"(SELECT idprocess FROM process WHERE ref_idmetaprocess IN " +
+				"(SELECT idmetaprocess FROM metaprocess WHERE ref_idsessionTask IN " +
+				"(SELECT ref_idsessionTask FROM session_has_sessionTask WHERE ref_idsession=" +
+				"(SELECT session FROM productionDirectory WHERE idproductionDirectory=" + productionDirectoryId +
+				")))))";
+		
+		BiomajLogger.getInstance().log("Deleting process messages", BiomajLogger.INFO_LEVEL);
+		connection.executeUpdate(query, stat);
+		
+		// Metaprocess messages
+		query = "DELETE FROM message WHERE idmessage IN " +
+				"(SELECT ref_idmessage FROM metaprocess_has_message WHERE ref_idmetaprocess IN " +
+				"(SELECT idmetaprocess FROM metaprocess WHERE ref_idsessionTask IN " +
+				"(SELECT ref_idsessionTask FROM session_has_sessionTask WHERE ref_idsession=" +
+				"(SELECT session FROM productionDirectory WHERE idproductionDirectory=" + productionDirectoryId +
+				"))))";
+		
+		BiomajLogger.getInstance().log("Deleting metaprocess messages", BiomajLogger.INFO_LEVEL);
+		connection.executeUpdate(query, stat);
+		
+		// SessionTask messages
+		query = "DELETE FROM message WHERE idmessage IN " +
+				"(SELECT ref_idmessage FROM sessionTask_has_message WHERE ref_idsessionTask IN " +
+				"(SELECT ref_idsessionTask FROM session_has_sessionTask WHERE ref_idsession=" +
+				"(SELECT session FROM productionDirectory WHERE idproductionDirectory=" + productionDirectoryId +
+				")))";
+		
+		BiomajLogger.getInstance().log("Deleting sessionTask messages", BiomajLogger.INFO_LEVEL);
+		connection.executeUpdate(query, stat);
+		
+		// Session messages
+		query = "DELETE FROM message WHERE idmessage IN " +
+				"(SELECT ref_idmessage FROM session_has_message WHERE ref_idsession=" +
+				"(SELECT session FROM productionDirectory WHERE idproductionDirectory=" + productionDirectoryId +
+				"))";
+		
+		BiomajLogger.getInstance().log("Deleting session messages", BiomajLogger.INFO_LEVEL);
+		connection.executeUpdate(query, stat);
+		
+		SQLConnectionFactory.closeConnection(stat);
+	}
 
 }
